@@ -153,6 +153,11 @@ KEY is a symbol denoting the kind of required information."
     (if lang-slot
 	(cdr (assq key (cdr lang-slot))))))
 
+(defun mule-frob-after-load-hack (string)
+  (if (> emacs-minor-version 4)
+      (concat string ".elc")
+    string))
+
 (defun set-language-info (language-name key info)
   "Set for LANGUAGE-NAME the information INFO under KEY.
 KEY is a symbol denoting the kind of information.
@@ -210,7 +215,7 @@ if you want to use your own KEY values, make them start with `user-'."
 	       (setq info (car info)))
 	   (when (featurep 'menubar)
 	     (eval-after-load
-	      "x-menubar"
+	      (mule-frob-after-load-hack "x-menubar")
 	      `(add-menu-button
 		'("Mule" "Describe Language Support")
 		(vector ,language-name
@@ -230,7 +235,7 @@ if you want to use your own KEY values, make them start with `user-'."
 	       (setq info (car info)))
 	   (when (featurep 'menubar)
 	     (eval-after-load
-	      "x-menubar"
+	      (mule-frob-after-load-hack "x-menubar")
 	      `(add-menu-button
 		'("Mule" "Set Language Environment")
 		(vector ,language-name
