@@ -363,7 +363,7 @@ point. When in sexp-mode this is the overlay for the expression after point.")
 	  (mic-paren-highlight)
 	(error 
 	 (if (not (window-minibuffer-p (selected-window)))
-	     (message "mic-paren catched error (please report): %s"
+	     (message "mic-paren caught an error (please report): %s"
 		      paren-error))))))
 
 (defun mic-paren-command-idle-hook ()
@@ -371,7 +371,7 @@ point. When in sexp-mode this is the overlay for the expression after point.")
       (mic-paren-highlight)
     (error 
      (if (not (window-minibuffer-p (selected-window)))
-	 (message "mic-paren catched error (please report): %s" 
+	 (message "mic-paren caught an error (please report): %s" 
 		  paren-error)))))
 
 
@@ -413,8 +413,8 @@ cleaning-up."
 	 ;;    highlight unmatched paren
 	 ;;    print no-match message
 	 (if open
-	     (let ((mismatch (/= (matching-paren (preceding-char)) 
-				 (char-after open)))
+	     (let ((mismatch (not (eq (matching-paren (preceding-char)) 
+				      (char-after open))))
 		   (visible (pos-visible-in-window-p open)))
 	       ;; If highlight is appropriate
 	       ;;    highlight
