@@ -1213,7 +1213,7 @@ For tips and answers to frequently asked questions, see the XEmacs FAQ.
     (when site-lisp
       ;; If the site-lisp dir isn't on the load-path, add it to the end.
       (or (member site-lisp load-path)
-	  (setq load-path (append load-path (list site-lisp))))
+	  (setq load-path (append load-path (list (concat site-lisp "/")))))
       ;; Also add any direct subdirectories of the site-lisp directory
       ;; to the load-path.  But don't add dirs whose names begin
       ;; with dot or hyphen.
@@ -1233,7 +1233,7 @@ For tips and answers to frequently asked questions, see the XEmacs FAQ.
     (when lisp
       ;; If the lisp dir isn't on the load-path, add it to the end.
       (or (member lisp load-path)
-	  (setq load-path (append load-path (list lisp))))
+	  (setq load-path (append load-path (list (concat lisp "/")))))
       ;; Also add any direct subdirectories of the lisp directory
       ;; to the load-path.  But don't add dirs whose names begin
       ;; with dot or hyphen.
